__author__ = 'cjoakim'
__version__ = '0.3.0'

"""
ggps library
"""

VERSION = __version__

from ggps.trackpoint import Trackpoint
from ggps.base_handler import BaseHandler
from ggps.gpx_handler import GpxHandler
from ggps.path_handler import PathHandler
from ggps.tcx_handler import TcxHandler
